==> python-sympy-1.6.2-1-any.pkg.tar.xz: usr/lib/python3.8/site-packages/sympy/physics/mechanics/__init__.py <==
__all__ = [
    'vector',

    'CoordinateSym', 'ReferenceFrame', 'Dyadic', 'Vector', 'Point', 'cross',
    'dot', 'express', 'time_derivative', 'outer', 'kinematic_equations',
    'get_motion_params', 'partial_velocity', 'dynamicsymbols', 'vprint',
    'vsstrrepr', 'vsprint', 'vpprint', 'vlatex', 'init_vprinting', 'curl',
    'divergence', 'gradient', 'is_conservative', 'is_solenoidal',
    'scalar_potential', 'scalar_potential_difference',

    'KanesMethod',

    'RigidBody',

    'inertia', 'inertia_of_point_mass', 'linear_momentum', 'angular_momentum',
    'kinetic_energy', 'potential_energy', 'Lagrangian', 'mechanics_printing',
    'mprint', 'msprint', 'mpprint', 'mlatex', 'msubs', 'find_dynamicsymbols',

    'Particle',

    'LagrangesMethod',

    'Linearizer',

    'Body',

    'SymbolicSystem',
]

from sympy.physics import vector

from sympy.physics.vector import (CoordinateSym, ReferenceFrame, Dyadic, Vector, Point,
        cross, dot, express, time_derivative, outer, kinematic_equations,
        get_motion_params, partial_velocity, dynamicsymbols, vprint,
        vsstrrepr, vsprint, vpprint, vlatex, init_vprinting, curl, divergence,
        gradient, is_conservative, is_solenoidal, scalar_potential,
        scalar_potential_difference)

from .kane import KanesMethod

from .rigidbody import RigidBody

from .functions import (inertia, inertia_of_point_mass, linear_momentum,
        angular_momentum, kinetic_energy, potential_energy, Lagrangian,
        mechanics_printing, mprint, msprint, mpprint, mlatex, msubs,
        find_dynamicsymbols)

from .particle import Particle

from .lagrange import LagrangesMethod

from .linearize import Linearizer

from .body import Body

from .system import SymbolicSystem

==> python-sympy-1.11.1-1-any.pkg.tar.xz: usr/lib/python3.10/site-packages/sympy/physics/mechanics/__init__.py <==
__all__ = [
    'vector',

    'CoordinateSym', 'ReferenceFrame', 'Dyadic', 'Vector', 'Point', 'cross',
    'dot', 'express', 'time_derivative', 'outer', 'kinematic_equations',
    'get_motion_params', 'partial_velocity', 'dynamicsymbols', 'vprint',
    'vsstrrepr', 'vsprint', 'vpprint', 'vlatex', 'init_vprinting', 'curl',
    'divergence', 'gradient', 'is_conservative', 'is_solenoidal',
    'scalar_potential', 'scalar_potential_difference',

    'KanesMethod',

    'RigidBody',

    'inertia', 'inertia_of_point_mass', 'linear_momentum', 'angular_momentum',
    'kinetic_energy', 'potential_energy', 'Lagrangian', 'mechanics_printing',
    'mprint', 'msprint', 'mpprint', 'mlatex', 'msubs', 'find_dynamicsymbols',

    'Particle',

    'LagrangesMethod',

    'Linearizer',

    'Body',

    'SymbolicSystem',

    'PinJoint', 'PrismaticJoint',

    'JointsMethod'
]

from sympy.physics import vector

from sympy.physics.vector import (CoordinateSym, ReferenceFrame, Dyadic, Vector, Point,
        cross, dot, express, time_derivative, outer, kinematic_equations,
        get_motion_params, partial_velocity, dynamicsymbols, vprint,
        vsstrrepr, vsprint, vpprint, vlatex, init_vprinting, curl, divergence,
        gradient, is_conservative, is_solenoidal, scalar_potential,
        scalar_potential_difference)

from .kane import KanesMethod

from .rigidbody import RigidBody

from .functions import (inertia, inertia_of_point_mass, linear_momentum,
        angular_momentum, kinetic_energy, potential_energy, Lagrangian,
        mechanics_printing, mprint, msprint, mpprint, mlatex, msubs,
        find_dynamicsymbols)

from .particle import Particle

from .lagrange import LagrangesMethod

from .linearize import Linearizer

from .body import Body

from .system import SymbolicSystem

from .jointsmethod import JointsMethod

from .joint import PinJoint, PrismaticJoint
